From be59fe2d668d42353d4f6f457d0bc23b5f240401 Mon Sep 17 00:00:00 2001
From: Ying Fang <fangying1@huawei.com>
Date: Sat, 20 Feb 2021 16:16:17 +0800
Subject: [PATCH] vhost-vsock/test: Check if /dev/vhost-vsock exist

If testcase runs inside a container environment, /dev/vhost-vsock may not
exist then return directly.

Signed-off-by: Ying Fang <fangying1@huawei.com>
---
 device_model/src/virtio/vhost/kernel/vsock.rs | 22 ++++++++++++++-----
 1 file changed, 17 insertions(+), 5 deletions(-)

diff --git a/device_model/src/virtio/vhost/kernel/vsock.rs b/device_model/src/virtio/vhost/kernel/vsock.rs
index 36b6f7a..59f513e 100644
--- a/device_model/src/virtio/vhost/kernel/vsock.rs
+++ b/device_model/src/virtio/vhost/kernel/vsock.rs
@@ -282,17 +282,14 @@ mod tests {
     }
 
     #[test]
-    fn test_vsock() {
+    fn test_vsock_init() {
         // test vsock new method
         let mut vsock = vsock_create_instance();
+
         assert_eq!(vsock.device_features, 0);
         assert_eq!(vsock.driver_features, 0);
         assert!(vsock.backend.is_none());
 
-        // test vsock realize method
-        assert!(vsock.realize().is_ok());
-        assert!(vsock.backend.is_some());
-
         assert_eq!(vsock.device_type(), VIRTIO_TYPE_VSOCK);
         assert_eq!(vsock.queue_num(), QUEUE_NUM_VSOCK);
         assert_eq!(vsock.queue_size(), QUEUE_SIZE_VSOCK);
@@ -343,6 +340,21 @@ mod tests {
         let mut buf: [u8; 4] = [0; 4];
         assert_eq!(vsock.read_config(5, &mut buf).is_err(), true);
         assert_eq!(vsock.read_config(3, &mut buf).is_err(), true);
+    }
+
+    #[test]
+    fn test_vsock_realize() {
+        // test vsock new method
+        let mut vsock = vsock_create_instance();
+
+        // return directly if /dev/vhost-vsock does not exist
+        if !std::path::Path::new(VHOST_PATH).exists() {
+            return;
+        }
+
+        // test vsock realize method
+        assert!(vsock.realize().is_ok());
+        assert!(vsock.backend.is_some());
 
         // test vsock set_guest_cid
         let backend = vsock.backend.unwrap();
-- 
2.27.0

